@@ -1,20 +1,23 @@
 import os
+from copy import deepcopy
 from pathlib import Path
-from typing import Optional, Callable
+from typing import Optional
 
 from git import Repo
 
-from flexlate.add_mode import AddMode
-from flexlate.config import FlexlateConfig
-from flexlate.config_manager import ConfigManager
+from flexlate.add_mode import AddMode, get_expanded_out_root
+from flexlate.branch_update import modify_files_via_branches_and_temp_repo
+from flexlate.config_manager import (
+    ConfigManager,
+    determine_config_path_from_roots_and_add_mode,
+)
 from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRANCH_NAME
-from flexlate.exc import GitRepoDirtyException
 from flexlate.ext_git import (
-    checked_out_template_branch,
-    stage_and_commit_all,
-    merge_branch_into_current,
     assert_repo_is_in_clean_state,
 )
+from flexlate.path_ops import (
+    location_relative_to_new_parent,
+)
 from flexlate.render.multi import MultiRenderer
 from flexlate.template.base import Template
 from flexlate.template_data import TemplateData
@@ -38,7 +41,20 @@ class Adder:
         if repo.working_dir is None:
             raise ValueError("repo working dir should not be none")
 
-        config_path = _determine_config_path(out_root, Path(repo.working_dir), add_mode)
+        config_path = determine_config_path_from_roots_and_add_mode(
+            out_root, Path(repo.working_dir), add_mode
+        )
+        project_root = Path(repo.working_dir)
+
+        if not template.path.is_absolute() and not (config_path.parent.resolve() == Path(os.getcwd())):
+            # Relative path, if the config output location is different than the
+            # current directory, need to adjust the path to be relative to
+            # the config output location
+
+            # Don't overwrite existing template
+            template = deepcopy(template)
+            # Make template path relative to its config file rather than current directory
+            template.path = Path(os.path.relpath(template.path.resolve(), config_path.parent.resolve()))
 
         if add_mode == AddMode.USER:
             # No need to use git if adding for user
@@ -51,17 +67,20 @@ class Adder:
             return
 
         # Local or project config, add in git
-        _add_operation_via_branches(
-            lambda: config_manager.add_template_source(
+        modify_files_via_branches_and_temp_repo(
+            lambda temp_path: config_manager.add_template_source(
                 template,
-                config_path,
+                location_relative_to_new_parent(
+                    config_path, project_root, temp_path, Path(os.getcwd())
+                ),
                 target_version=target_version,
-                project_root=Path(repo.working_dir),  # type: ignore
+                project_root=temp_path,
             ),
             repo,
             _add_template_source_commit_message(
                 template, out_root, Path(repo.working_dir)
             ),
+            out_root,
             merged_branch_name=merged_branch_name,
             template_branch_name=template_branch_name,
         )
@@ -85,10 +104,10 @@ class Adder:
             raise ValueError("repo working dir should not be none")
 
         project_root = Path(repo.working_dir)
-        config_path = _determine_config_path(out_root, project_root, add_mode)
-        expanded_out_root = (
-            out_root.absolute() if add_mode == AddMode.USER else out_root
+        config_path = determine_config_path_from_roots_and_add_mode(
+            out_root, project_root, add_mode
         )
+        expanded_out_root = get_expanded_out_root(out_root, project_root, add_mode)
 
         if add_mode == AddMode.USER:
             # No need to commit config changes for user
@@ -100,48 +119,32 @@ class Adder:
                 out_root=expanded_out_root,
             )
         else:
-            # TODO: restructure the current path logic into _add_operation_via_branches
-            #  as it will also be needed for other operations.
             # Commit changes for local and project
-            cwd = Path(os.getcwd())
-            absolute_out_root = out_root.absolute()
-            def make_dirs_add_applied_template():
-                # Need to ensure that both cwd and out root exist on the template branch
-                for p in [cwd, absolute_out_root]:
-                    if not p.exists():
-                        p.mkdir(parents=True)
-                # If cwd was deleted when switching branches, need to navigate back there
-                # or os.getcwd will throw a FileNotExistsError (which also breaks path.absolute())
-                os.chdir(cwd)
-
-                config_manager.add_applied_template(
+            modify_files_via_branches_and_temp_repo(
+                lambda temp_path: config_manager.add_applied_template(
                     template,
-                    config_path,
+                    location_relative_to_new_parent(
+                        config_path, project_root, temp_path, Path(os.getcwd())
+                    ),
                     data=data,
-                    project_root=project_root,
+                    project_root=temp_path,
                     out_root=expanded_out_root,
-                )
-
-            _add_operation_via_branches(
-                make_dirs_add_applied_template,
+                ),
                 repo,
                 _add_template_commit_message(
                     template, out_root, Path(repo.working_dir)
                 ),
+                out_root,
                 merged_branch_name=merged_branch_name,
                 template_branch_name=template_branch_name,
             )
-
-            # Folder may have been deleted again while switching branches, so
-            # need to set cwd again
-            os.chdir(cwd)
-
         template_update = TemplateUpdate(
             template=template,
             config_location=config_path,
             index=config_manager.get_num_applied_templates_in_child_config(
                 config_path, project_root=project_root
-            ) - 1,
+            )
+            - 1,
             data=data,
         )
 
@@ -182,9 +185,9 @@ class Adder:
             return
 
         # Config resides in project, so add it via branches
-        _add_operation_via_branches(
-            lambda: config_manager.add_project(
-                path=path,
+        modify_files_via_branches_and_temp_repo(
+            lambda temp_path: config_manager.add_project(
+                path=temp_path,
                 default_add_mode=default_add_mode,
                 user=user,
                 merged_branch_name=merged_branch_name,
@@ -192,50 +195,12 @@ class Adder:
             ),
             repo,
             "Initialized flexlate project",
+            path,
             merged_branch_name=merged_branch_name,
             template_branch_name=template_branch_name,
         )
 
 
-def _determine_config_path(
-    out_root: Path = Path("."),
-    project_root: Path = Path("."),
-    add_mode: AddMode = AddMode.LOCAL,
-) -> Path:
-    if add_mode == AddMode.USER:
-        return FlexlateConfig._settings.config_location
-    if add_mode == AddMode.PROJECT:
-        return project_root / "flexlate.json"
-    if add_mode == AddMode.LOCAL:
-        return out_root / "flexlate.json"
-    raise ValueError(f"unexpected add mode {add_mode}")
-
-
-def _add_operation_via_branches(
-    add_operation: Callable[[], None],
-    repo: Repo,
-    commit_message: str,
-    merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
-    template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
-):
-    current_branch = repo.active_branch
-
-    # Update the template only branch with the new template
-    with checked_out_template_branch(repo, branch_name=template_branch_name):
-        add_operation()
-        stage_and_commit_all(repo, commit_message)
-
-    # Bring the change into the merged branch
-    with checked_out_template_branch(repo, branch_name=merged_branch_name):
-        # Update with changes from the main repo
-        merge_branch_into_current(repo, current_branch.name)
-        # Update with the new template
-        merge_branch_into_current(repo, template_branch_name)
-
-    # Merge back into current branch
-    merge_branch_into_current(repo, merged_branch_name)
-
-
 def _add_template_commit_message(
     template: Template, out_root: Path, project_root: Path
 ) -> str:
