@@ -1,8 +1,9 @@
+import os
 from pathlib import Path
-from typing import List, Optional, Sequence, Dict, Any, Tuple, Union
+from typing import List, Optional, Sequence, Dict, Any, Tuple, Union, cast
 
 from pyappconf import BaseConfig, AppConfig, ConfigFormats
-from pydantic import BaseModel, Field, validator, Extra
+from pydantic import BaseModel, Field, validator, Extra, PrivateAttr
 
 from flexlate.add_mode import AddMode
 from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRANCH_NAME
@@ -10,7 +11,9 @@ from flexlate.exc import (
     InvalidTemplateTypeException,
     FlexlateProjectConfigFileNotExistsException,
 )
+from flexlate.finder.specific.base import TemplateFinder
 from flexlate.finder.specific.cookiecutter import CookiecutterFinder
+from flexlate.finder.specific.copier import CopierFinder
 from flexlate.template.base import Template
 from flexlate.template.types import TemplateType
 from flexlate.template_data import TemplateData
@@ -21,8 +24,10 @@ class TemplateSource(BaseModel):
     path: str
     type: TemplateType
     version: Optional[str] = None
-    target_version: Optional[str] = None
     git_url: Optional[str] = None
+    target_version: Optional[str] = None
+
+    _config_file_location: Path = PrivateAttr()
 
     @classmethod
     def from_template(
@@ -42,8 +47,11 @@ class TemplateSource(BaseModel):
             raise InvalidTemplateTypeException(
                 "base type is not allowed for concrete templates"
             )
+        finder: TemplateFinder
         if self.type == TemplateType.COOKIECUTTER:
             finder = CookiecutterFinder()
+        elif self.type == TemplateType.COPIER:
+            finder = CopierFinder()
         else:
             raise InvalidTemplateTypeException(
                 f"no handling for template type {self.type} in creating template from source"
@@ -51,9 +59,17 @@ class TemplateSource(BaseModel):
         kwargs = dict(name=self.name)
         if self.version is not None:
             kwargs.update(version=self.version)
+        if self.target_version is not None:
+            kwargs.update(target_version=self.target_version)
         if self.git_url is not None:
             kwargs.update(git_url=self.git_url)
-        return finder.find(self.path, **kwargs)
+        local_path: Path
+        if Path(self.path).is_absolute():
+            local_path = Path(self.path)
+        else:
+            # Convert to absolute path
+            local_path = (self._config_file_location.parent / Path(self.path)).resolve()
+        return finder.find(self.git_url or str(local_path), local_path, **kwargs)
 
     @property
     def update_location(self) -> Union[str, Path]:
@@ -91,10 +107,9 @@ class FlexlateConfig(BaseConfig):
         configs = _load_nested_configs(
             root, file_name, root, adjust_applied_paths=adjust_applied_paths
         )
-        if not configs:
-            # Fall back to user config if it exists
-            if cls._settings.config_location.exists():
-                configs = [cls.load()]
+        # Add user config if it exists
+        if cls._settings.config_location.exists():
+            configs.append(cls.load())
         return cls.from_multiple(configs)
 
     @classmethod
@@ -127,12 +142,34 @@ class FlexlateConfig(BaseConfig):
     def child_configs(self) -> List["FlexlateConfig"]:
         return self._child_configs or []
 
+    @property
+    def empty(self) -> bool:
+        return len(self.template_sources) == 0 and len(self.applied_templates) == 0
+
+    @classmethod
+    def load(cls, path: Optional[Union[str, Path]] = None) -> "FlexlateConfig":
+        config = cast(FlexlateConfig, super().load(path))
+        for template_source in config.template_sources:
+            # Add location from which config was loaded so that later template source paths
+            # can be made absolute before usage
+            loaded_path = path or cls._settings.config_location
+            template_source._config_file_location = Path(loaded_path)
+        return config
+
     def save(self, serializer_kwargs: Optional[Dict[str, Any]] = None, **kwargs):
         if not self.child_configs:
             # Normal singular config, fall back to py-app-conf behavior
             return super().save(serializer_kwargs, **kwargs)
         # Parent pseudo-config holding actual child configs, save those instead
         for config in self.child_configs:
+            if config.empty:
+                # User must have removed all the sources and applied templates,
+                # therefore we don't want the config file anymore
+                if config.settings.config_location.exists():
+                    os.remove(config.settings.config_location)
+                continue
+
+            # Normal case, non-empty config, save it
             config.save(serializer_kwargs, **kwargs)
 
     class Config:
