@@ -34,6 +34,14 @@ class TemplateNotRegisteredException(FlexlateTemplateException):
     pass
 
 
+class CannotFindTemplateSourceException(FlexlateTemplateException):
+    pass
+
+
+class CannotFindClonedTemplateException(FlexlateTemplateException):
+    pass
+
+
 class FlexlateGitException(FlexlateException):
     pass
 
@@ -54,6 +62,18 @@ class CannotLoadConfigException(FlexlateConfigException):
     pass
 
 
+class CannotRemoveConfigItemException(FlexlateConfigException):
+    pass
+
+
+class CannotRemoveTemplateSourceException(CannotRemoveConfigItemException):
+    pass
+
+
+class CannotRemoveAppliedTemplateException(CannotRemoveConfigItemException):
+    pass
+
+
 class FlexlateConfigFileNotExistsException(CannotLoadConfigException):
     pass
 
