@@ -2,17 +2,21 @@ import os
 import shutil
 import tempfile
 from pathlib import Path
-from typing import Sequence, Optional, List, Dict
+from typing import Sequence, Optional, List, Dict, Final
 
 from flexlate.exc import InvalidTemplateClassException, RendererNotFoundException
 from flexlate.render.renderable import Renderable
 from flexlate.render.specific.base import SpecificTemplateRenderer
 from flexlate.render.specific.cookiecutter import CookiecutterRenderer
+from flexlate.render.specific.copier import CopierRenderer
 from flexlate.template.base import Template
 from flexlate.template.types import TemplateType
 from flexlate.template_data import TemplateData
 
-renderers = [CookiecutterRenderer()]
+renderers: Final[List[SpecificTemplateRenderer]] = [
+    CookiecutterRenderer(),
+    CopierRenderer(),
+]
 
 
 class MultiRenderer:
@@ -35,14 +39,14 @@ class MultiRenderer:
                 temp_folder = temp_root / f"{i + 1}-{template.name}"
                 temp_folders.append(temp_folder)
                 if renderable.out_root.is_absolute():
-                    relative_root = renderable.out_root.relative_to(project_root.absolute())
+                    relative_root = renderable.out_root.relative_to(
+                        project_root.absolute()
+                    )
                 else:
                     relative_root = renderable.out_root
                 new_root = temp_folder / relative_root
-                temp_renderable = renderable.copy(update=dict(out_root = new_root))
-                template_data = renderer.render(
-                    temp_renderable, no_input=no_input
-                )
+                temp_renderable = renderable.copy(update=dict(out_root=new_root))
+                template_data = renderer.render(temp_renderable, no_input=no_input)
                 out_data.append(template_data)
             _merge_file_trees(temp_folders, project_root)
         return out_data
