@@ -1,3 +1,4 @@
+import os
 from pathlib import Path
 from typing import Sequence, Optional, List, Dict, Any
 
@@ -5,25 +6,26 @@ from git import Repo
 
 from flexlate.config_manager import ConfigManager
 from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRANCH_NAME
-from flexlate.exc import GitRepoDirtyException
 from flexlate.finder.multi import MultiFinder
+from flexlate.path_ops import make_all_dirs, location_relative_to_new_parent
 from flexlate.render.multi import MultiRenderer
 from flexlate.render.renderable import Renderable
 from flexlate.template.base import Template
 from flexlate.ext_git import (
-    delete_tracked_files,
     stage_and_commit_all,
     merge_branch_into_current,
-    checked_out_template_branch,
     checkout_template_branch,
     repo_has_merge_conflicts,
     assert_repo_is_in_clean_state,
+    temp_repo_that_pushes_to_branch,
+    fast_forward_branch_without_checkout,
 )
 from flexlate.template_data import TemplateData, merge_data
 from flexlate.update.template import (
     TemplateUpdate,
     updates_with_updated_data,
 )
+from tests.dirutils import display_contents_of_all_files_in_folder
 
 
 class Updater:
@@ -46,22 +48,39 @@ class Updater:
 
         # Prepare the template branch, this is the branch that stores only the template files
         # Create it from the initial commit if it does not exist
-        with checked_out_template_branch(repo, branch_name=template_branch_name):
-            config_manager.update_templates(updates, project_root=out_path)
-            renderables = config_manager.get_renderables(project_root=out_path)
-            updated_data = renderer.render(
-                renderables, project_root=out_path, no_input=no_input
+        cwd = Path(os.getcwd())
+        with temp_repo_that_pushes_to_branch(  # type: ignore
+            repo, branch_name=template_branch_name, delete_tracked_files=True
+        ) as temp_repo:
+            temp_out_path = Path(temp_repo.working_dir)  # type: ignore
+            temp_updates = _move_update_config_locations_to_new_parent(
+                updates, out_path, temp_out_path
             )
-            new_updates = updates_with_updated_data(updates, updated_data)
-            config_manager.update_templates(new_updates, project_root=out_path)
-            stage_and_commit_all(repo, _commit_message(renderables))
+            config_manager.update_templates(temp_updates, project_root=temp_out_path)
+            renderables = _move_renderable_out_roots_to_new_parent(
+                config_manager.get_renderables(project_root=temp_out_path),
+                out_path,
+                temp_out_path,
+            )
+
+            _create_cwd_and_directories_if_needed(
+                cwd, [renderable.out_root for renderable in renderables]
+            )
+            updated_data = renderer.render(
+                renderables, project_root=temp_out_path, no_input=no_input
+            )
+            new_updates = updates_with_updated_data(temp_updates, updated_data)
+            config_manager.update_templates(new_updates, project_root=temp_out_path)
+            stage_and_commit_all(temp_repo, _commit_message(renderables))
 
         # Now prepare the merged (output) branch, by merging the current
         # branch into it and then the template branch into it.
-        checkout_template_branch(repo, merged_branch_name)
         # Update with changes from the main repo
-        merge_branch_into_current(repo, current_branch.name)
+        fast_forward_branch_without_checkout(
+            repo, merged_branch_name, current_branch.name
+        )
         # Update with template changes
+        checkout_template_branch(repo, merged_branch_name)
         merge_branch_into_current(repo, template_branch_name)
 
         if not repo_has_merge_conflicts(repo):
@@ -118,6 +137,7 @@ class Updater:
                 # Template needs to be upgraded
                 # As finder already updates the local files, just update the template object
                 template.version = new_template.version
+                template.path = new_template.path
 
 
 def _commit_message(renderables: Sequence[Renderable]) -> str:
@@ -126,3 +146,44 @@ def _commit_message(renderables: Sequence[Renderable]) -> str:
         template = renderable.template
         message += f"{template.name}: {template.version}\n"
     return message
+
+
+def _create_cwd_and_directories_if_needed(cwd: Path, directories: Sequence[Path]):
+    make_all_dirs([cwd])
+
+    # Folder may have been deleted again while switching branches, so
+    # need to set cwd again
+    os.chdir(cwd)
+
+    make_all_dirs(directories)
+
+
+def _move_update_config_locations_to_new_parent(
+    updates: Sequence[TemplateUpdate], orig_parent: Path, new_parent: Path
+) -> List[TemplateUpdate]:
+    cwd = Path(os.getcwd())
+    return [
+        update.copy(
+            update=dict(
+                config_location=location_relative_to_new_parent(
+                    update.config_location, orig_parent, new_parent, cwd
+                )
+            )
+        )
+        for update in updates
+    ]
+
+
+def _move_renderable_out_roots_to_new_parent(
+    renderbales: Sequence[Renderable], orig_parent: Path, new_parent: Path
+) -> List[Renderable]:
+    return [
+        renderable.copy(
+            update=dict(
+                out_root=location_relative_to_new_parent(
+                    renderable.out_root, orig_parent, new_parent, orig_parent
+                )
+            )
+        )
+        for renderable in renderbales
+    ]
