@@ -2,6 +2,7 @@ import shutil
 import tempfile
 from pathlib import Path
 from typing import Optional, Sequence
+from unittest.mock import patch
 
 import pytest
 from git import Repo, Head
@@ -21,6 +22,7 @@ from tests.config import (
     COOKIECUTTER_REMOTE_VERSION_1,
     COOKIECUTTER_REMOTE_VERSION_2,
     COOKIECUTTER_ONE_VERSION,
+    COOKIECUTTER_ONE_NAME,
 )
 from tests.fileutils import (
     cookiecutter_one_generated_text_content,
@@ -48,9 +50,9 @@ def test_update_template_dirty_repo(
 
 def test_update_modify_template(
     cookiecutter_one_modified_template: CookiecutterTemplate,
-    repo_with_template_branch_from_cookiecutter_one: Repo,
+    repo_with_gitignore_and_template_branch_from_cookiecutter_one: Repo,
 ):
-    repo = repo_with_template_branch_from_cookiecutter_one
+    repo = repo_with_gitignore_and_template_branch_from_cookiecutter_one
     updater = Updater()
     template_updates = updater.get_updates_for_templates(
         [cookiecutter_one_modified_template], project_root=GENERATED_REPO_DIR
@@ -61,12 +63,24 @@ def test_update_modify_template(
     assert repo.active_branch == main_branch
     assert (
         repo.commit().message
-        == "Update flexlate templates\n\none: 7e18a6cc14856c8558ac999efa01e5e8\n"
+        == "Merge branch 'flexlate-templates' into flexlate-output\n"
     )
-    assert cookiecutter_one_generated_text_content(gen_dir=GENERATED_REPO_DIR) == " and extra"
+    assert (
+        repo.commit().parents[1].message
+        == f"Update flexlate templates\n\none: {COOKIECUTTER_ONE_MODIFIED_VERSION}\n"
+    )
+    assert (
+        cookiecutter_one_generated_text_content(gen_dir=GENERATED_REPO_DIR)
+        == "b and extra"
+    )
+    assert (GENERATED_REPO_DIR / "ignored" / "ignored.txt").exists()
+    assert (GENERATED_REPO_DIR / ".gitignore").exists()
     template_branch.checkout()
     assert repo.active_branch == template_branch
-    assert cookiecutter_one_generated_text_content(gen_dir=GENERATED_REPO_DIR) == " and extra"
+    assert (
+        cookiecutter_one_generated_text_content(gen_dir=GENERATED_REPO_DIR)
+        == "b and extra"
+    )
 
 
 def test_update_modify_template_conflict(
@@ -91,7 +105,7 @@ def test_update_passed_templates_to_newest_versions(
 ):
     wipe_generated_folder()
     local_template = cookiecutter_one_template
-    _modify_template_in_generated_folder(local_template)
+    _modify_cookiecutter_one_template_in_generated_folder(local_template)
     updater = Updater()
     finder = MultiFinder()
     remote_template = finder.find(
@@ -118,7 +132,7 @@ def test_update_passed_templates_to_newest_versions(
         [remote_template, local_template], config_manager=MockConfigManager()  # type: ignore
     )
     assert remote_template.version == COOKIECUTTER_REMOTE_VERSION_2
-    assert local_template.version == "8d9453d0a0e376965b4edd74a395e47d"
+    assert local_template.version == "471c7dbeea2541fe9a7a558d3aafb6e0"
 
 
 def test_update_passed_templates_to_newest_versions_but_already_at_targets(
@@ -126,7 +140,7 @@ def test_update_passed_templates_to_newest_versions_but_already_at_targets(
 ):
     wipe_generated_folder()
     local_template = cookiecutter_one_template
-    _modify_template_in_generated_folder(local_template)
+    _modify_cookiecutter_one_template_in_generated_folder(local_template)
     updater = Updater()
     finder = MultiFinder()
     remote_template = finder.find(
@@ -162,7 +176,8 @@ def test_update_passed_templates_to_newest_versions_but_already_at_targets(
     assert local_template.version == COOKIECUTTER_ONE_VERSION
 
 
-def _modify_template_in_generated_folder(template: Template):
-    shutil.copytree(template.path, GENERATED_FILES_DIR, dirs_exist_ok=True)
-    template.path = GENERATED_FILES_DIR
-    (GENERATED_FILES_DIR / "some file.txt").touch()
+def _modify_cookiecutter_one_template_in_generated_folder(template: Template):
+    template_folder = GENERATED_FILES_DIR / COOKIECUTTER_ONE_NAME
+    shutil.copytree(template.path, template_folder, dirs_exist_ok=True)
+    template.path = template_folder
+    (template_folder / "some file.txt").touch()
